<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin CompteSPIP
 *
 * @plugin     comptespip
 * @copyright  2020
 * @author     tofulm
 * @licence    GNU/GPL
 * @package    SPIP\CompteSPIP\Installation
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Fonction d'installation et de mise à jour du plugin CompteSPIP.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible
 *     Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 * @return void
**/
function comptespip_upgrade($nom_meta_base_version, $version_cible) {
	$maj = array();

	$maj['create'] = array();
	$maj['1.0.3'] = array(array('comptespip_creer_slug', array('mail_inscription', [])));

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}

/**
 * si Gamumail est actif, créer le slug pour le mail d'inscription afin de donner la main aux admins pour son contenu
 **/
function comptespip_creer_slug($nom_slug, $options = []) {
	if (test_plugin_actif('gamumail')) {
		$cree_slug = charger_fonction('creer_slug', 'action');
		$message = _T('form_forum_message_auto')."\r\n"."\r\n"._T('form_forum_bonjour', array('nom' => '@@nom@@'))."\r\n"."\r\n";
		$message .= _T('comptespip:confirmation_creation_compte', array('url_site' => '@@url_site@@'));
		$set = [
			'titre'  	=> _T('comptespip:mail_inscription'),
			'sujet'  	=> '['.lire_config('nom_site').'] '._T('comptespip:creation_compte'),
			'texte'  	=> $message,
			'statut'	=> 'publie',
			'editable' 	=> 'non',
		];
		$cree_slug('mail_inscription', $set);
	}
}

/**
 * Fonction de désinstallation du plugin CompteSPIP.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @return void
**/
function comptespip_vider_tables($nom_meta_base_version) {

	effacer_meta($nom_meta_base_version);
}
